import java.io.*;
import java.util.*;
import java.math.*;

public class A implements Runnable {
	private static BufferedReader in;
	private static StringTokenizer st;
	private static PrintWriter out;

	class Edge {
		int u, v;

		public Edge(int u, int v) {
			this.u = u;
			this.v = v;
		}
	}

	enum QueryType {
		REMOVE, QUERY, ADD;
	}

	class Query {
		QueryType queryType;
		int id;

		public Query(QueryType queryType, int id) {
			this.queryType = queryType;
			this.id = id;
		}
	}

	class DSU {
		private int[] ids;
		private int components;

		private int historySize;
		private int[] historyKey, historyValue;

		final int maxHistorySize = 5000000;

		public DSU(int size) {
			this.ids = new int[size];
			this.components = size;
			for (int i = 0; i < size; i++)
				this.ids[i] = i;

			this.historySize = 0;
			this.historyKey = new int[maxHistorySize];
			this.historyValue = new int[maxHistorySize];
		}

		public int find(int id) {
			if (this.ids[id] == id)
				return id;
			this.historyKey[this.historySize] = id;
			this.historyValue[this.historySize] = this.ids[id];
			++this.historySize;
			return this.ids[id] = find(this.ids[id]);
		}

		public void merge(int a, int b) {
			a = find(a);
			b = find(b);
			if (a != b) {
				--this.components;
				this.historyKey[this.historySize] = a;
				this.historyValue[this.historySize] = this.ids[a];
				++this.historySize;
				this.ids[a] = b;
			}
		}

		public int store() {
			return this.historySize;
		}

		public void restore(int sizeWas) {
			while (this.historySize > sizeWas) {
				--this.historySize;
				this.ids[this.historyKey[this.historySize]] = this.historyValue[this.historySize];
			}
		}

		public void setComponents(int components) {
			this.components = components;
		}

		public int getComponents() {
			return this.components;
		}
	}

	class FastSet {
		private int timer;
		private int[] values;

		public FastSet(int size) {
			this.timer = 1;
			this.values = new int[size];
		}

		public void clear() {
			this.timer++;
		}

		public boolean contains(int u) {
			return this.values[u] == timer;
		}

		public void add(int u) {
			this.values[u] = timer;
		}
	}

	private void rec(int l, int r, Query[] queries, DSU dsu, boolean[] result,
			FastSet leftSet, FastSet rightSet, Edge[] edges) {
		if (l == r) {
			Query query = queries[l];
			if (query.queryType == QueryType.QUERY) {
				result[query.id] = (dsu.getComponents() == 1);
			}
		} else {
			int m = (l + r) / 2;
			int dsuState = dsu.store();
			int componentsWas = dsu.getComponents();

			leftSet.clear();
			rightSet.clear();

			for (int i = l; i <= m; i++) {
				Query query = queries[i];
				if (query.queryType == QueryType.REMOVE
						|| query.queryType == QueryType.ADD) {
					leftSet.add(query.id);
				}
			}

			for (int i = m + 1; i <= r; i++) {
				Query query = queries[i];
				if (query.queryType == QueryType.ADD) {
					rightSet.add(query.id);
				} else if (query.queryType == QueryType.REMOVE
						&& !leftSet.contains(query.id)
						&& !rightSet.contains(query.id)) {
					Edge edge = edges[query.id];
					dsu.merge(edge.u, edge.v);
					rightSet.add(query.id);
				}
			}

			rec(l, m, queries, dsu, result, leftSet, rightSet, edges);

			dsu.restore(dsuState);
			dsu.setComponents(componentsWas);

			leftSet.clear();
			rightSet.clear();

			for (int i = m + 1; i <= r; i++) {
				Query query = queries[i];
				if (query.queryType == QueryType.REMOVE) {
					rightSet.add(query.id);
				}
			}

			for (int i = m; i >= l; i--) {
				Query query = queries[i];
				if (query.queryType == QueryType.REMOVE) {
					leftSet.add(query.id);
				} else if (query.queryType == QueryType.ADD
						&& !leftSet.contains(query.id)
						&& !rightSet.contains(query.id)) {
					Edge edge = edges[query.id];
					dsu.merge(edge.u, edge.v);
					leftSet.add(query.id);
				}
			}

			rec(m + 1, r, queries, dsu, result, leftSet, rightSet, edges);

		}
	}

	private void solve() throws IOException {
		int verticesCount = nextInt(), edgesCount = nextInt();
		Edge[] edges = new Edge[edgesCount];
		for (int i = 0; i < edgesCount; i++) {
			edges[i] = new Edge(nextInt() - 1, nextInt() - 1);
		}
		List<Query> allQueries = new ArrayList<Query>();
		for (int i = 0; i < edgesCount; i++) {
			allQueries.add(new Query(QueryType.ADD, i));
		}
		int initQueriesCount = nextInt();
		final int maxQuerySize = 4;
		int[] currentEdges = new int[maxQuerySize];
		for (int i = 0; i < initQueriesCount; i++) {
			int m = nextInt();
			for (int j = 0; j < m; j++) {
				currentEdges[j] = nextInt() - 1;
				allQueries.add(new Query(QueryType.REMOVE, currentEdges[j]));
			}
			allQueries.add(new Query(QueryType.QUERY, i));
			for (int j = 0; j < m; j++) {
				allQueries.add(new Query(QueryType.ADD, currentEdges[j]));
			}
		}
		int queriesSize = allQueries.size();
		boolean[] result = new boolean[initQueriesCount];
		Query[] queries = new Query[queriesSize];
		for (int i = 0; i < queriesSize; i++) {
			queries[i] = allQueries.get(i);
		}
		DSU dsu = new DSU(verticesCount);
		FastSet leftSet = new FastSet(edgesCount);
		FastSet rightSet = new FastSet(edgesCount);
		rec(0, queriesSize - 1, queries, dsu, result, leftSet, rightSet, edges);
		for (int i = 0; i < initQueriesCount; i++) {
			out.println(result[i] ? "Connected" : "Disconnected");
		}
	}

	public void run() {
		final String className = this.getClass().getName().toLowerCase();

		try {
			try {
				in = new BufferedReader(new FileReader(className + ".in"));
				out = new PrintWriter(new FileWriter(className + ".out"));
			} catch (FileNotFoundException e) {
				in = new BufferedReader(new InputStreamReader(System.in));
				out = new PrintWriter(System.out);
			}

			solve();

			out.close();
		} catch (IOException e) {
			e.printStackTrace();
			System.exit(1);
		}
	}

	public static void main(String[] args) {
		new A().run();
		// new Thread(null, new Template(), "Template", (1L << 24)).start();
	}

	private String nextToken() throws IOException {
		while (st == null || !st.hasMoreTokens()) {
			String line = in.readLine();
			if (line == null) {
				return null;
			}
			st = new StringTokenizer(line);
		}
		return st.nextToken();
	}

	private int nextInt() throws IOException {
		return Integer.parseInt(nextToken());
	}

	private long nextLong() throws IOException {
		return Long.parseLong(nextToken());
	}

	private double nextDouble() throws IOException {
		return Double.parseDouble(nextToken());
	}

}
